=== renamed directory 'plugin/test_authz' => 'plugin/simple_user_policy'
=== renamed file 'plugin/test_authz/test_authz.cc' => 'plugin/simple_user_policy/module.cc'
--- plugin/test_authz/test_authz.cc	2010-03-06 02:08:13 +0000
+++ plugin/simple_user_policy/module.cc	2010-04-15 19:14:53 +0000
@@ -19,57 +19,21 @@
 
 #include "config.h"
 
-#include <string>
-
-#include "drizzled/plugin/authorization.h"
-#include "drizzled/security_context.h"
-
+#include <drizzled/plugin/authorization.h>
+
+#include "policy.h"
 
 using namespace drizzled;
 
-namespace authz
-{
-
-class Authz :
-  public plugin::Authorization
-{
-public:
-  Authz() :
-    plugin::Authorization("test authz")
-  { }
-
-  /* I told you it was a silly plugin.
-    If the db name is authz_no and the user is authz, then it's blocked
-    If it's anything else, it's approved
-  */
-  virtual bool restrictSchema(const SecurityContext &user_ctx,
-                              const std::string &db)
-  {
-    if (db == "authz_no" and user_ctx.getUser() == "authz")
-      return true;
-    return false;
-  }
-
-  virtual bool restrictProcess(const SecurityContext &user_ctx,
-                               const SecurityContext &session_ctx)
-  {
-    if (user_ctx.getUser() == session_ctx.getUser())
-      return false;
-    if (user_ctx.getUser() == "authz")
-      return true;
-    return false;
-  }
-};
-
-Authz *authz= NULL;
+namespace simple_user_policy
+{
 
 static int init(plugin::Context &context)
 {
-  authz= new Authz();
-  context.add(authz);
+  context.add(new Policy);
   return 0;
 }
 
-} /* namespace authz */
+} /* namespace simple_user_policy */
 
-DRIZZLE_PLUGIN(authz::init, NULL);
+DRIZZLE_PLUGIN(simple_user_policy::init, NULL);

=== modified file 'plugin/simple_user_policy/plugin.ini'
--- plugin/test_authz/plugin.ini	2010-03-02 18:59:12 +0000
+++ plugin/simple_user_policy/plugin.ini	2010-04-15 19:14:53 +0000
@@ -1,6 +1,8 @@
 [plugin]
-title=Test Authorization
-description=A simple authorization plugin simply for testing that it works
+title=Simple User Policy
+description=Authorization plugin which implements a simple policy-based strategy
 version=1.0
 author=Monty Taylor <mordred@inaugust.com>
 license=PLUGIN_LICENSE_GPL
+sources=module.cc
+headers=policy.h

=== added file 'plugin/simple_user_policy/policy.h'
--- plugin/simple_user_policy/policy.h	1970-01-01 00:00:00 +0000
+++ plugin/simple_user_policy/policy.h	2010-04-15 19:14:53 +0000
@@ -0,0 +1,66 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor <mordred@inaugust.com>
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#ifndef PLUGINS_SIMPLE_USER_POLICY_POLICY_H
+#define PLUGINS_SIMPLE_USER_POLICY_POLICY_H
+
+#include <iostream>
+
+#include <drizzled/plugin/authorization.h>
+
+namespace simple_user_policy
+{
+
+class Policy :
+  public drizzled::plugin::Authorization
+{
+public:
+  Policy() :
+    drizzled::plugin::Authorization("Simple User Policy")
+  { }
+
+  virtual bool restrictSchema(const drizzled::SecurityContext &user_ctx,
+                              drizzled::SchemaIdentifier &db);
+
+  virtual bool restrictProcess(const drizzled::SecurityContext &user_ctx,
+                               const drizzled::SecurityContext &session_ctx);
+};
+
+inline bool Policy::restrictSchema(const drizzled::SecurityContext &user_ctx,
+                                   drizzled::SchemaIdentifier &schema)
+{
+  if ((user_ctx.getUser() == "root")
+      || schema.compare("data_dictionary")
+      || schema.compare("information_schema"))
+    return false;
+  return not schema.compare(user_ctx.getUser());
+}
+
+inline bool Policy::restrictProcess(const drizzled::SecurityContext &user_ctx,
+                                    const drizzled::SecurityContext &session_ctx)
+{
+  if (user_ctx.getUser() == "root")
+    return false;
+  return user_ctx.getUser() != session_ctx.getUser();
+}
+
+} /* namespace simple_user_policy */
+
+#endif /* PLUGINS_SIMPLE_USER_POLICY_POLICY_H */

=== modified file 'plugin/simple_user_policy/tests/r/basic.result'
--- plugin/test_authz/tests/r/basic.result	2010-03-02 18:59:12 +0000
+++ plugin/simple_user_policy/tests/r/basic.result	2010-04-15 19:14:53 +0000
@@ -1,57 +1,72 @@
-create database authz_no;
-SELECT * from authz_no.dont_exist;
-ERROR 42S02: Table 'authz_no.dont_exist' doesn't exist
-create database authz_yes;
-show databases;
-Database
-authz_no
-authz_yes
-data_dictionary
-information_schema
-mysql
-test
-show databases;
-Database
-authz_yes
-data_dictionary
-information_schema
-mysql
-test
-SELECT * from authz_no.dont_exist;
-ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to database 'authz_no'
-create database authz_no;
-ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to database 'authz_no'
-drop database authz_no;
-ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to database 'authz_no'
-show processlist;
-ID	USER	HOST	DB	COMMAND	TIME	STATE	INFO
-1	root	#	test	#	#	#	
-2	authz	#	test	#	#	#	
-3	root	#	test	#	#	#	show processlist
-4	root	#	test	#	#	#	show processlist
-create table t1 (kill_id int);
-insert into t1 values(connection_id());
-select ((@id := kill_id) - kill_id) from t1;
-((@id := kill_id) - kill_id)
-0
-kill @id;
-select ((@id := kill_id) - kill_id) from t1;
-((@id := kill_id) - kill_id)
-0
-select @id != connection_id();
-@id != connection_id()
-1
-update t1 set kill_id= connection_id();
-show processlist;
-ID	USER	HOST	DB	COMMAND	TIME	STATE	INFO
-2	authz	#	test	Query	#	Sending data	show processlist
-select ((@id := kill_id) - kill_id) from t1;
-((@id := kill_id) - kill_id)
-0
-kill @id;
-ERROR HY000: Unknown thread id: 5
+create database user1;
+create database user2;
+show databases;
+Database
+DATA_DICTIONARY
+INFORMATION_SCHEMA
+mysql
+test
+user1
+user2
+use user2;
+create table t1 (kill_id int);
+insert into t1 values(connection_id());
+SELECT * from user1.dont_exist;
+ERROR 42S02: Table 'user1.dont_exist' doesn't exist
+show databases;
+Database
+DATA_DICTIONARY
+INFORMATION_SCHEMA
+user1
+SELECT * from user2.dont_exist;
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'user2'
+create database authorize_fail;
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'authorize_fail'
+drop database user2;
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'user2'
+create table t1 (kill_id int);
+insert into t1 values(connection_id());
+show processlist;
+ID	USER	HOST	DB	COMMAND	TIME	STATE	INFO
+2	user1	#	user1	#	#	#	
+3	user1	#	user1	#	#	#	show processlist
+select ((@id := kill_id) - kill_id) from t1;
+((@id := kill_id) - kill_id)
+0
+kill @id;
+select ((@id := kill_id) - kill_id) from t1;
+((@id := kill_id) - kill_id)
+0
+select @id != connection_id();
+@id != connection_id()
+1
+update t1 set kill_id = connection_id();
+show processlist;
+ID	USER	HOST	DB	COMMAND	TIME	STATE	INFO
+4	user2	#	user2	#	#	#	show processlist
+select ((@id := kill_id) - kill_id) from t1;
+((@id := kill_id) - kill_id)
+0
+kill @id;
+ERROR HY000: Unknown thread id: 1
+show processlist;
+ID	USER	HOST	DB	COMMAND	TIME	STATE	INFO
+1	root	#	user2	#	#	#	show processlist
+3	user1	#	user1	#	#	#	show processlist
+4	user2	#	user2	#	#	#	show processlist
+5	user1	#	user1	#	#	#	update t1 set kill_id = connection_id()
+use user1;
+select ((@id := kill_id) - kill_id) from t1;
+((@id := kill_id) - kill_id)
+0
+kill @id;
+select ((@id := kill_id) - kill_id) from t1;
+((@id := kill_id) - kill_id)
+0
+select @id != connection_id();
+@id != connection_id()
+1
 connect(localhost,authz,,authz_no,MASTER_PORT,);
 ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to database 'authz_no'
-drop table t1;
-drop schema authz_yes;
-drop schema authz_no;
+drop schema user1;
+drop schema user2;

=== modified file 'plugin/simple_user_policy/tests/t/basic-master.opt'
--- plugin/test_authz/tests/t/basic-master.opt	2010-03-02 18:59:12 +0000
+++ plugin/simple_user_policy/tests/t/basic-master.opt	2010-04-15 19:14:53 +0000
@@ -1,1 +1,1 @@
---plugin-add=test_authz
+--plugin-add=simple_user_policy

=== renamed file 'plugin/test_authz/tests/t/basic.disabled' => 'plugin/simple_user_policy/tests/t/basic.test'
--- plugin/test_authz/tests/t/basic.disabled	2010-03-31 05:53:34 +0000
+++ plugin/simple_user_policy/tests/t/basic.test	2010-04-15 19:14:53 +0000
@@ -1,71 +1,120 @@
 # Check for error if no parameter provided
-create database authz_no;
+create database user1;
+create database user2;
+show databases;
+
+# Set up a table to be able to test not being able to kill other people
+use user2;
+create table t1 (kill_id int);
+insert into t1 values(connection_id());
+
+# Test that we get a normal don't exist error for things that don't exist
 --error ER_NO_SUCH_TABLE
-SELECT * from authz_no.dont_exist;
-create database authz_yes;
-show databases;
+SELECT * from user1.dont_exist;
+
+# Connect as user1 - should only see information_schema, user1 and
+# data_dictionary
+# Also tests that we are able to read data_dictionary, without which fail
+# would happen
 --replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
-connect (should_succeed,localhost,authz,test,,);
+connect (should_succeed,localhost,user1,,user1,,);
 connection should_succeed;
 show databases;
---replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
---replace_regex /@'.*?'/@'LOCALHOST'/
---error ER_DBACCESS_DENIED_ERROR
-SELECT * from authz_no.dont_exist;
---replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
---replace_regex /@'.*?'/@'LOCALHOST'/
---error ER_DBACCESS_DENIED_ERROR
-create database authz_no;
---replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
---replace_regex /@'.*?'/@'LOCALHOST'/
---error ER_DBACCESS_DENIED_ERROR
-drop database authz_no;
-
---replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
-connect (con1,localhost,root,test,,);
---replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
-connect (con2,localhost,root,test,,);
+
+# Test that we get blocked on not being allowed to see user2 at all before
+# we get blocked on the table not existing
+--replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
+--replace_regex /@'.*?'/@'LOCALHOST'/
+--error ER_DBACCESS_DENIED_ERROR
+SELECT * from user2.dont_exist;
+
+# Test that we can't create a schema that isn't named the same as we are
+--replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
+--replace_regex /@'.*?'/@'LOCALHOST'/
+--error ER_DBACCESS_DENIED_ERROR
+create database authorize_fail;
+
+# Test that we can't drop a schema that isn't named the same as we are
+--replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
+--replace_regex /@'.*?'/@'LOCALHOST'/
+--error ER_DBACCESS_DENIED_ERROR
+drop database user2;
+
+# Set up a table to test that we can kill other versions of us
+create table t1 (kill_id int);
+insert into t1 values(connection_id());
+
+--replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
+connect (con1,localhost,user1,,user1,);
+--replace_result $MASTER_MYSOCK MASTER_SOCKET $MASTER_MYPORT MASTER_PORT
+connect (con2,localhost,user2,,user2,);
 connection con1;
 
+# Check that we don't see other people's connections
 --replace_column 3 # 5 # 6 # 7 #
 show processlist;
 
+# Check that we can kill a process that is owned by our user
 --disable_reconnect
-create table t1 (kill_id int);
-insert into t1 values(connection_id());
-
+select ((@id := kill_id) - kill_id) from t1;
+kill @id;
+
+connection should_succeed;
+--sleep 2
+
+--disable_query_log
+--disable_result_log
+# One of the following statements should fail
+--error 0,5,20,23
+select 1;
+--error 0,5,20,23
+select 1;
+--enable_query_log
+--enable_result_log
+--enable_reconnect
+
+select ((@id := kill_id) - kill_id) from t1;
+select @id != connection_id();
+
+# Set the table to our current id now
+update t1 set kill_id = connection_id();
+
+# Test that we cannot kill a process owned by someone else
 connection con2;
-select ((@id := kill_id) - kill_id) from t1;
-kill @id;
-
-connection con1;
---sleep 2
-
---disable_query_log
---disable_result_log
-# One of the following statements should fail
---error 0,5,20,23
-select 1;
---error 0,5,20,23
-select 1;
---enable_query_log
---enable_result_log
---enable_reconnect
-
-select ((@id := kill_id) - kill_id) from t1;
-select @id != connection_id();
-
-update t1 set kill_id= connection_id();
-
-connection should_succeed;
---replace_column 3 # 6 #
+--replace_column 3 # 5 # 6 # 7 #
 show processlist;
 select ((@id := kill_id) - kill_id) from t1;
 
 --error ER_NO_SUCH_THREAD
 kill @id;
 
-
+# Test that root can see everybody
+connection default;
+--replace_column 3 # 5 # 6 # 7 #
+show processlist;
+
+# Test that root can kill someone else
+use user1;
+--disable_reconnect
+select ((@id := kill_id) - kill_id) from t1;
+kill @id;
+
+connection should_succeed;
+--sleep 2
+
+--disable_query_log
+--disable_result_log
+# One of the following statements should fail
+--error 0,5,20,23
+select 1;
+--error 0,5,20,23
+select 1;
+--enable_query_log
+--enable_result_log
+--enable_reconnect
+
+select ((@id := kill_id) - kill_id) from t1;
+select @id != connection_id();
 
 
 # Test failing initial connection
@@ -74,7 +123,10 @@
 --error ER_DBACCESS_DENIED_ERROR
 connect (should_fail,localhost,authz,,authz_no,,);
 
+# Clean up after ourselves
 connection default;
-drop table t1;
-drop schema authz_yes;
-drop schema authz_no;
+drop schema user1;
+drop schema user2;
+disconnect con1;
+disconnect con2;
+disconnect should_succeed;

